@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package App::Cronjob;
 # ABSTRACT: wrap up programs to be run as cron jobs
-$App::Cronjob::VERSION = '1.200005';
+$App::Cronjob::VERSION = '1.200006';
 use Digest::MD5 qw(md5_hex);
 use Errno;
 use Fcntl qw( :DEFAULT :flock );
@@ -104,8 +104,8 @@ sub run {
         );
       }
 
-      printf $lock_fh "running %s\nstarted at %s\n",
-        $opt->{command}, scalar localtime $^T;
+      printf $lock_fh "pid %s running %s\nstarted at %s\n",
+        $$, $opt->{command}, scalar localtime $^T;
 
       $got_lock = 1;
     }
@@ -234,7 +234,7 @@ END_TEMPLATE
 
 {
   package App::Cronjob::Exception;
-$App::Cronjob::Exception::VERSION = '1.200005';
+$App::Cronjob::Exception::VERSION = '1.200006';
 sub new {
     my ($class, $type, $text, $extra) = @_;
     bless { type => $type, text => $text, extra => $extra } => $class;
@@ -255,7 +255,7 @@ App::Cronjob - wrap up programs to be run as cron jobs
 
 =head1 VERSION
 
-version 1.200005
+version 1.200006
 
 =head1 SEE INSTEAD
 
